@@ -1,14 +1,14 @@
 ### -*- coding: utf-8 -*- #############################################
 """Adapter of division to attribute dir component.
 
-$Id: attributediradapter.py 49222 2008-01-06 04:47:35Z cray $
+$Id: attributediradapter.py 49313 2008-01-09 13:47:57Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49222 $"
+__version__ = "$Revision: 49313 $"
 
 
-from ng.ftp.attributedirectory import AttributeDirBase
+from ng.ftp.readattributes import AttributeDirBase
 from zope.interface import Interface,implements,providedBy
 from ng.ftp.interfaces import IAttributeDir
 
