@@ -1,11 +1,11 @@
 ### -*- coding: utf-8 -*- #############################################
 """Container adapters the Zope 3 based contentobjects package
 
-$Id: ftpwidget.py 49222 2008-01-06 04:47:35Z cray $
+$Id: ftpwidget.py 49359 2008-01-11 21:15:19Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49222 $"
+__version__ = "$Revision: 49359 $"
 
 from zope.interface import implements
 from zope.component import adapts
@@ -27,12 +27,15 @@ class FtpWidgetBase(object) :
     def context(self) :
         return removeSecurityProxy(self.field).context
 
-
     def convertor(self,value) :
-        return value 
-        
+        try :
+            return eval(value)
+        except SyntaxError,msg :
+            print "FIXME:",self,msg,value
+            return value            
+
     def serialize(self,value) :
-        return str(value)        
+        return repr(value)        
         
     def write(self,value) :
         self.field.set(self.context,self.convertor(value))
@@ -48,23 +51,37 @@ class FtpWidgetBase(object) :
         
 class FieldWidget(FtpWidgetBase) :
     adapts(IField)
-    
-    def convertor(self,value) :
-        return eval(value)
 
 class TextWidget(FtpWidgetBase) :
     adapts(IText)
+
+    def convertor(self,value) :
+        return unicode(value)
+        
+    def serialize(self,value) :
+        return str(value)
     
 class BytesWidget(FtpWidgetBase) :
     adapts(IBytes)
 
+    def convertor(self,value) :
+        return value
+        
+    def serialize(self,value) :
+        return value
+
+
 class DateTimeWidget(FtpWidgetBase) :
     adapts(IDatetime)
     fmt = "%Y-%m-%d %M:%H:%S"
     len = 19
 
     def convertor(self,value) :
-        return datetime.datetime(*(strptime(value[0:self.len],self.fmt)[0:-2]+(zope.datetime.tzinfo(int(value[self.len:])),) ))
+        try :
+            tz = int(value[self.len:])
+        except ValueError :
+            tz = 0
+        return datetime.datetime(*(strptime(value[0:self.len],self.fmt)[0:-2]+(zope.datetime.tzinfo(0),) ))
         
     def serialize(self,value) :
         try :
